# VMNIC

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**external_ip_address** | **str** |  | [optional] 
**internal_ip_address** | **str** |  | [optional] 
**network_address** | **str** |  | [optional] 
**network_id** | **str** |  | [optional] 
**security_group_ids** | **list[str]** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


